var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { mergeArraysFromRight } from "../utils/arrays";
export default function reducer(state, action) {
    switch (action.type) {
        case "CACHE_FILES": {
            if (state.cacheKey) {
                var entry = { files: state.files, timestamp: Date.now() };
                localStorage.setItem(state.cacheKey, JSON.stringify(entry));
            }
            return state;
        }
        case "INITIALIZE_FILES":
            return __assign(__assign({}, state), { files: action.payload });
        case "INITIALIZE_FILES_WITH_CACHE": {
            var payload = action.payload;
            var cacheKey = payload.cacheKey;
            var cached = getCachedFileEntry(cacheKey);
            if (cached && cached.timestamp > payload.timestamp) {
                var files = mergeArraysFromRight(payload.files, cached.files, function (a, b) { return a.fullName === b.fullName; });
                return { cacheKey: cacheKey, files: files };
            }
            return { cacheKey: cacheKey, files: payload.files };
        }
        case "RESET": {
            var files = state.files.map(function (x) { return (__assign(__assign({}, x), { content: x.originalContent })); });
            if (state.cacheKey) {
                localStorage.removeItem(state.cacheKey);
            }
            return __assign(__assign({}, state), { files: files });
        }
        case "UPDATE_FILE": {
            var files = state.files.map(function (x) {
                return x.fullName !== action.payload.fullName ? x : action.payload;
            });
            var cacheKey = state.cacheKey;
            if (cacheKey) {
                var entry = { files: files, timestamp: Date.now() };
                localStorage.setItem(cacheKey, JSON.stringify(entry));
            }
            return { cacheKey: cacheKey, files: files };
        }
    }
}
var getCachedFileEntry = function (key) {
    var _a;
    var cached = (_a = localStorage.getItem(key)) !== null && _a !== void 0 ? _a : "";
    try {
        var parsed = JSON.parse(cached);
        if (isCacheEntry(parsed)) {
            return parsed;
        }
    }
    catch (e) { }
    return undefined;
};
var isCacheEntry = function (data) {
    if (!Array.isArray(data.files))
        return false;
    if (!data.files.every(function (x) { return isFileEntry(x); }))
        return false;
    if (typeof data.timestamp !== "number")
        return false;
    return true;
};
var isFileEntry = function (data) {
    if (typeof data.content !== "string")
        return false;
    if (typeof data.fullName !== "string")
        return false;
    if (typeof data.originalContent !== "string")
        return false;
    if (typeof data.shortName !== "string")
        return false;
    return true;
};
//# sourceMappingURL=fileEntryReducer.js.map